@@ -84,7 +84,8 @@ EditVarWidget <- function(ExistingItems=NULL,container=NULL,title=NULL,ID=NULL,s
   button <- gtkButtonNewWithLabel("Save and Close")
   gSignalConnect(button, "clicked",saveFUN,list(model,window,ExistingItems,list(...)))
   hbox$packStart(button, TRUE, TRUE, 0)
-  window$setDefaultSize(200, 350)
+  window$setDefaultSize(300, 350)
+  window$Move(size(.rqda$.root_rqdagui)[1],2)
   window$showAll()
   invisible(window)
 }
@@ -118,7 +119,7 @@ saveFUN4CaseAttr <- function(button,data){
     if (any(mod_idx)) {
     ## alter the table for the modified variable
     vars <- ans[mod_idx,]
-    apply(vars,1,FUN=function(x) dbGetQuery(.rqda$qdacon,sprintf("update caseAttr set value == '%s' where variable == '%s' and caseID=='%s' and status==1",x[2],x[1],MoreArgs$caseId)))
+    apply(vars,1,FUN=function(x) dbGetQuery(.rqda$qdacon,sprintf("update caseAttr set value = '%s' where variable = '%s' and caseID ='%s' and status =1",x[2],x[1],MoreArgs$caseId)))
     }
     if (any(new_idx)){
     ## add the new variable to table
@@ -130,10 +131,10 @@ saveFUN4CaseAttr <- function(button,data){
 }
 
 CaseAttrFun <- function(caseId,title=NULL,attrs=svalue(.rqda$.AttrNamesWidget)){
-  if (length(attrs)==0) attrs <-  dbGetQuery(.rqda$qdacon,"select name from attributes where status==1")$name
+  if (length(attrs)==0) attrs <-  dbGetQuery(.rqda$qdacon,"select name from attributes where status=1")$name
   if (is.null(attrs)) gmessage("add attribute in Attrs Tabe first.",con=T) else{
     attrs2 <- data.frame(variable=attrs,value="NA",stringsAsFactors=FALSE)
-    variables <- dbGetQuery(.rqda$qdacon,sprintf("select variable, value from caseAttr where caseID==%i and variable in (%s) and status==1", caseId,paste(shQuote(attrs),collapse=",")))
+    variables <- dbGetQuery(.rqda$qdacon,sprintf("select variable, value from caseAttr where caseID=%i and variable in (%s) and status=1", caseId,paste(shQuote(attrs),collapse=",")))
     if (nrow(variables)!=0){
       Encoding(variables$variable) <- Encoding(variables$value) <- 'UTF-8'
       idx <- match(variables[[1]],attrs2[[1]])
@@ -172,7 +173,7 @@ saveFUN4FileAttr <- function(button,data){
     if (any(mod_idx)) {
     ## alter the table for the modified variable
     vars <- ans[mod_idx,]
-    apply(vars,1,FUN=function(x) dbGetQuery(.rqda$qdacon,sprintf("update fileAttr set value == '%s' where variable == '%s' and fileID=='%s'and status==1",x[2],x[1],MoreArgs$fileId)))
+    apply(vars,1,FUN=function(x) dbGetQuery(.rqda$qdacon,sprintf("update fileAttr set value = '%s' where variable = '%s' and fileID ='%s'and status=1",x[2],x[1],MoreArgs$fileId)))
     }
     if (any(new_idx)){
     ## add the new variable to table
@@ -184,11 +185,11 @@ saveFUN4FileAttr <- function(button,data){
 }
 
 FileAttrFun <- function(fileId,title=NULL,attrs=svalue(.rqda$.AttrNamesWidget)){
-  if (length(attrs)==0) attrs <-  dbGetQuery(.rqda$qdacon,"select name from attributes where status==1")$name
+  if (length(attrs)==0) attrs <-  dbGetQuery(.rqda$qdacon,"select name from attributes where status=1")$name
   if (is.null(attrs)) gmessage("add attribute in Attrs Tabe first.",con=T) else{
     Encoding(attrs) <- 'UTF-8'
     attrs2 <- data.frame(variable=attrs,value="NA",stringsAsFactors=FALSE)
-    variables <- dbGetQuery(.rqda$qdacon,sprintf("select variable, value from fileAttr where fileID==%i and variable in (%s) and status==1",fileId,paste(shQuote(attrs),collapse=",")))
+    variables <- dbGetQuery(.rqda$qdacon,sprintf("select variable, value from fileAttr where fileID=%i and variable in (%s) and status=1",fileId,paste(shQuote(attrs),collapse=",")))
     if (nrow(variables)!=0){
       Encoding(variables$variable) <- Encoding(variables$value) <- 'UTF-8'
       idx <- match(variables[[1]],attrs2[[1]])
@@ -204,7 +205,7 @@ FileAttrFun <- function(fileId,title=NULL,attrs=svalue(.rqda$.AttrNamesWidget)){
 
 AttrNamesUpdate <- function(Widget=.rqda$.AttrNamesWidget,sortByTime=FALSE,decreasing=FALSE,...)
 {
-  if (isIdCurrent(.rqda$qdacon)){
+  if (is_projOpen()){
     attr <- dbGetQuery(.rqda$qdacon, "select name, date from attributes where status=1")
     if (nrow(attr)==0) {
       attr <- NULL
@@ -222,7 +223,7 @@ AttrNamesUpdate <- function(Widget=.rqda$.AttrNamesWidget,sortByTime=FALSE,decre
 AddAttrNames <- function(name,...) {
   if (name != ""){
     con <- .rqda$qdacon
-    dup <- dbGetQuery(con,sprintf("select name from attributes where name=='%s'",name))
+    dup <- dbGetQuery(con,sprintf("select name from attributes where name='%s'",name))
     if (nrow(dup)==0) {
       dbGetQuery(con,sprintf("insert into attributes (name,status,date,owner) values ('%s', %i,%s, %s)",
                              name,1, shQuote(date()),shQuote(.rqda$owner)))
@@ -261,9 +262,9 @@ DeleteAttrButton <- function(label="Delete"){
     if (isTRUE(del)){
       Selected <- svalue(.rqda$.AttrNamesWidget)
       Selected <- enc(Selected,"UTF-8")
-      dbGetQuery(.rqda$qdacon,sprintf("update attributes set status=0 where name=='%s'",Selected))
-      RQDAQuery(sprintf("update caseAttr set status==0 where variable=='%s'",Selected))
-      RQDAQuery(sprintf("update fileAttr set status==0 where variable=='%s'",Selected))
+      dbGetQuery(.rqda$qdacon,sprintf("update attributes set status=0 where name='%s'",Selected))
+      RQDAQuery(sprintf("update caseAttr set status=0 where variable='%s'",Selected))
+      RQDAQuery(sprintf("update fileAttr set status=0 where variable='%s'",Selected))
       AttrNamesUpdate()
     }
   }
@@ -285,13 +286,13 @@ RenameAttrButton <- function(label="Rename"){
       if (invalid) {
         gmessage("Attribute should NOT contain '.",con=TRUE)
       } else {
-        exists <- dbGetQuery(.rqda$qdacon, sprintf("select * from attributes where name == '%s' ",NewName))
+        exists <- dbGetQuery(.rqda$qdacon, sprintf("select * from attributes where name = '%s' ",NewName))
         if (nrow(exists) > 0 ){
           gmessage("Name duplicated. Please use anaother name.",cont=TRUE)
         } else {
-          dbGetQuery(.rqda$qdacon, sprintf("update attributes set name = '%s' where name == '%s' ",NewName,selected))
-          dbGetQuery(.rqda$qdacon, sprintf("update caseAttr set variable = '%s' where variable == '%s' ",NewName,selected))
-          dbGetQuery(.rqda$qdacon, sprintf("update fileAttr set variable = '%s' where variable == '%s' ",NewName,selected))
+          dbGetQuery(.rqda$qdacon, sprintf("update attributes set name = '%s' where name = '%s' ",NewName,selected))
+          dbGetQuery(.rqda$qdacon, sprintf("update caseAttr set variable = '%s' where variable = '%s' ",NewName,selected))
+          dbGetQuery(.rqda$qdacon, sprintf("update fileAttr set variable = '%s' where variable = '%s' ",NewName,selected))
           AttrNamesUpdate()
         }
       }
@@ -314,10 +315,10 @@ AttrMemoButton <- function(label="Memo"){
 }
 
 viewCaseAttr <- function(){
-  DF <- dbGetQuery(.rqda$qdacon,"select variable,value, caseId from caseAttr where status==1")
+  DF <- dbGetQuery(.rqda$qdacon,"select variable,value, caseId from caseAttr where status=1")
   DF <- reshape(DF,v.name="value",idvar="caseID",direction="wide",timevar="variable")
   names(DF) <- gsub("^value.","",names(DF))
-  caseName <- dbGetQuery(.rqda$qdacon,"select name,id from cases where status==1")
+  caseName <- dbGetQuery(.rqda$qdacon,"select name,id from cases where status=1")
   if (nrow(caseName)!=0){
     names(caseName) <- c("case","caseID")
     Encoding(caseName$case) <- "UTF-8"
@@ -327,10 +328,10 @@ viewCaseAttr <- function(){
 }
 
 viewFileAttr <- function(){
-  DF <- dbGetQuery(RQDA:::.rqda$qdacon,"select variable,value, fileId from fileAttr where status==1")
+  DF <- dbGetQuery(RQDA:::.rqda$qdacon,"select variable,value, fileId from fileAttr where status=1")
   DF <- reshape(DF,v.name="value",idvar="fileID",direction="wide",timevar="variable")
   names(DF) <- gsub("^value.","",names(DF))
-  fileName <- dbGetQuery(.rqda$qdacon,"select name,id from source where status==1")
+  fileName <- dbGetQuery(.rqda$qdacon,"select name,id from source where status=1")
   if (nrow(fileName)!=0){
     names(fileName) <- c("file","fileID")
     Encoding(fileName$file) <- "UTF-8"
@@ -341,17 +342,19 @@ viewFileAttr <- function(){
 
 
 GetAttr <- function(type=c("case","file"),attrs=svalue(.rqda$.AttrNamesWidget),subset){
-  if (isIdCurrent(.rqda$qdacon)){
+  if (is_projOpen()){
   type <-  match.arg(type)
   if (length(attrs)==0) attrs <- NULL
-  inClause <- ifelse(is.null(attrs),"",sprintf("where status==1 and variable in (%s)",paste(shQuote(attrs),collapse=",")))
+  inClause <- ifelse(is.null(attrs),"",sprintf("where status=1 and variable in (%s)",paste(shQuote(attrs),collapse=",")))
   if (type == "case"){
+    RQDAQuery("delete from caseAttr where value='NA'")
+    RQDAQuery("delete from caseAttr where value=''") ## clean the table
     DF <- dbGetQuery(.rqda$qdacon,sprintf("select variable,value, caseId from caseAttr %s",inClause))
     if (nrow(DF) > 0 ){
     Encoding(DF$variable) <- Encoding(DF$value) <- "UTF-8"
     DF <- reshape(DF,v.name="value",idvar="caseID",direction="wide",timevar="variable")
     names(DF) <- gsub("^value.","",names(DF))
-    caseName <- dbGetQuery(.rqda$qdacon,"select name,id from cases where status==1")
+    caseName <- dbGetQuery(.rqda$qdacon,"select name,id from cases where status=1")
     if (nrow(caseName)!=0){
       names(caseName) <- c("case","caseID")
       Encoding(caseName$case) <- "UTF-8"
@@ -359,12 +362,14 @@ GetAttr <- function(type=c("case","file"),attrs=svalue(.rqda$.AttrNamesWidget),s
       class(DF) <- c("CaseAttr","data.frame")
     }}
   } else if (type=="file"){
+    RQDAQuery("delete from fileAttr where value='NA'")
+    RQDAQuery("delete from fileAttr where value=''") ## clean the table
     DF <- dbGetQuery(RQDA:::.rqda$qdacon,sprintf("select variable,value, fileId from fileAttr %s",inClause))
     if (nrow(DF) > 0 ){
     Encoding(DF$variable) <- Encoding(DF$value) <- "UTF-8"
     DF <- reshape(DF,v.name="value",idvar="fileID",direction="wide",timevar="variable")
     names(DF) <- gsub("^value.","",names(DF))
-    fileName <- dbGetQuery(.rqda$qdacon,"select name,id from source where status==1")
+    fileName <- dbGetQuery(.rqda$qdacon,"select name,id from source where status=1")
     if (nrow(fileName)!=0){
       names(fileName) <- c("file","fileID")
       Encoding(fileName$file) <- "UTF-8"
@@ -400,10 +405,10 @@ SetAttrClsButton <- function(label="Class"){
 
 setAttrType <- function() {
     Selected <- enc(svalue(.rqda$.AttrNamesWidget),encoding="UTF-8")
-    oldCls <- tryCatch(dbGetQuery(.rqda$qdacon,sprintf("select class from attributes where status==1 and name='%s'",Selected))[1,1],
+    oldCls <- tryCatch(dbGetQuery(.rqda$qdacon,sprintf("select class from attributes where status=1 and name='%s'",Selected))[1,1],
                        error=function(e){
                          dbGetQuery(RQDA:::.rqda$qdacon, "alter table attributes add column class text")
-                         dbGetQuery(.rqda$qdacon,sprintf("select class from attributes where status==1 and name='%s'",Selected))[1,1]
+                         dbGetQuery(.rqda$qdacon,sprintf("select class from attributes where status=1 and name='%s'",Selected))[1,1]
                        })
     if (is.null(oldCls)||is.na(oldCls)) {
       items <- c("unspecified","numeric","character")
@@ -417,12 +422,34 @@ setAttrType <- function() {
     rb <- gradio(items,idx,horizontal=TRUE, cont=gp)
     gbutton("OK",con=gp,handler=function(h,...){
       if ((newCls <- svalue(rb))!= "unspecified"){
-        dbGetQuery(.rqda$qdacon,sprintf("update attributes set class='%s' where status==1 and name='%s'",newCls,Selected))
+        dbGetQuery(.rqda$qdacon,sprintf("update attributes set class='%s' where status=1 and name='%s'",newCls,Selected))
       }
       dispose(w)
     })}
 
 
+importAttr <- function(data, type='file', filename){
+  idx <- match(filename, names(data))
+  dat <- data[, -idx,drop=FALSE]
+  fn <- getFiles()
+  fid <- getFiles(names=F)
+  fnuser <- data[,filename]
+  if (!all(fnuser %in% fn)) stop("some files are not in the rqda project.")
+  fid <- fid[match(data[[filename]],fn)]
+  allAtt <- RQDAQuery("select name from attributes where status=1")$name
+  if (!all(names(dat) %in% allAtt)) stop("some attributes are in not the rqda project.")
+  for (att in names(dat)) {
+    attval <- dat[[att]]
+    if (mode(attval) == "character" && Encoding(attval) != "UTF-8") attval <- iconv(attval, to='UTF-8')
+    for (i in 1:nrow(dat)) {
+      exist <- RQDAQuery(sprintf("select value from fileAttr where variable='%s' and fileID=%i and status=1", att, fid[i]))
+      if (nrow(exist)==0 && !is.na(attval[i])) {
+        RQDAQuery(sprintf("insert into fileAttr (variable, value, fileID, date, owner, status) 
+                          values ('%s','%s','%s','%s','rghuang',1)",att, attval[i], fid[i], as.character(date())))
+        }
+    }
+    }
+}
 
 #######################
 ## Defunct functions
