@@ -2,10 +2,10 @@ getCodingsByOne <- function(cid, fid=NULL,codingTable=c("coding","coding2")){
     if (length(cid)!=1) stop("cid should be length-1 integer vector.")
     codingTable <- match.arg(codingTable)
      if (codingTable=="coding"){
-    ct <- RQDAQuery(sprintf("select coding.rowid as rowid, coding.cid, coding.fid, freecode.name as codename, source.name as filename, coding.selfirst as index1, coding.selend as index2, coding.seltext as coding, coding.selend - coding.selfirst as CodingLength from coding left join freecode on (coding.cid=freecode.id) left join source on (coding.fid=source.id) where coding.status==1 and source.status=1 and freecode.status=1 and coding.cid=%s",cid))
+    ct <- RQDAQuery(sprintf("select coding.rowid as rowid, coding.cid, coding.fid, freecode.name as codename, source.name as filename, coding.selfirst as index1, coding.selend as index2, coding.seltext as coding, coding.selend - coding.selfirst as CodingLength from coding left join freecode on (coding.cid=freecode.id) left join source on (coding.fid=source.id) where coding.status=1 and source.status=1 and freecode.status=1 and coding.cid=%s",cid))
      }
      if (codingTable=="coding2"){
-    ct <- RQDAQuery(sprintf("select coding2.rowid as rowid, coding2.cid, coding2.fid, freecode.name as codename, source.name as filename, coding2.selfirst as index1, coding2.selend as index2, coding2.seltext as coding, coding2.selend - coding2.selfirst as CodingLength from coding2 left join freecode on (coding2.cid=freecode.id) left join source on (coding2.fid=source.id) where coding2.status==1 and source.status=1 and freecode.status=1 and coding2.cid=%s",cid))
+    ct <- RQDAQuery(sprintf("select coding2.rowid as rowid, coding2.cid, coding2.fid, freecode.name as codename, source.name as filename, coding2.selfirst as index1, coding2.selend as index2, coding2.seltext as coding, coding2.selend - coding2.selfirst as CodingLength from coding2 left join freecode on (coding2.cid=freecode.id) left join source on (coding2.fid=source.id) where coding2.status=1 and source.status=1 and freecode.status=1 and coding2.cid=%s",cid))
      }
     if (nrow(ct) != 0) {
         Encoding(ct$codename) <- Encoding(ct$filename) <- Encoding(ct$coding) <- "UTF-8"
@@ -123,7 +123,7 @@ and <- function (CT1, CT2)
         }
         if (nrow(ans) != 0){
             txt <- apply(ans,1,function(x){
-                txt <- RQDAQuery(sprintf("select file from source where id==%s",x[["fid"]]))[1,1]
+                txt <- RQDAQuery(sprintf("select file from source where id=%s",x[["fid"]]))[1,1]
                 Encoding(txt) <- "UTF-8"
                 ans <- substr(txt, as.numeric(x[["index1"]])+1, as.numeric(x[["index2"]]))
                 ans
@@ -173,7 +173,7 @@ or <- function (CT1, CT2)
         }
         if (nrow(ans) != 0){
             txt <- apply(ans,1,function(x){
-                txt <- RQDAQuery(sprintf("select file from source where id==%s",x[["fid"]]))[1,1]
+                txt <- RQDAQuery(sprintf("select file from source where id=%s",x[["fid"]]))[1,1]
                 Encoding(txt) <- "UTF-8"
                 ans <- substr(txt, as.numeric(x[["index1"]])+1, as.numeric(x[["index2"]]))
                 ans
@@ -222,7 +222,7 @@ not <- function (CT1, CT2)
         }
         if (nrow(ans) != 0){
             txt <- apply(ans,1,function(x){
-                txt <- RQDAQuery(sprintf("select file from source where id==%s",x[["fid"]]))[1,1]
+                txt <- RQDAQuery(sprintf("select file from source where id=%s",x[["fid"]]))[1,1]
                 Encoding(txt) <- "UTF-8"
                 ans <- substr(txt, as.numeric(x[["index1"]])+1, as.numeric(x[["index2"]]))
                 ans
