@@ -14,7 +14,7 @@ DeleteJournalButton <- function(label="Delete"){
         if (isTRUE(del)){
           Selected <- svalue(.rqda$.JournalNamesWidget)
           Encoding(Selected) <- "UTF-8"
-          RQDAQuery(sprintf("update journal set status=0 where name=='%s'",enc(Selected)))
+          RQDAQuery(sprintf("update journal set status=0 where name='%s'",enc(Selected)))
           JournalNamesUpdate()
         }
       }
@@ -53,13 +53,13 @@ OpenJournalButton <- function(label="Open")
 
 JournalNamesUpdate <- function(Widget=.rqda$.JournalNamesWidget,decreasing=FALSE,...)
 {
-  if (isIdCurrent(.rqda$qdacon)){
+  if (is_projOpen()){
     journal <- dbGetQuery(.rqda$qdacon, "select name from journal where status=1")
     if (nrow(journal)==0) {
       journal <- NULL
     } else {
       journal <- journal[,1]
-      journal <- journal[OrderByTime(journal,decreasing=decreasing)]
+      journal <- journal[OrderByTime(substring(journal,0,20),decreasing=decreasing)]
     }
     tryCatch(Widget[] <- journal, error=function(e){})
   }
@@ -76,9 +76,10 @@ AddNewJournalFun <- function(){
         assign(".AddNewJournalWidget",gw,env=.rqda)
         assign(".AddNewJournalWidget2",gpanedgroup(horizontal = FALSE, con=get(".AddNewJournalWidget",env=.rqda)),env=.rqda)
         gbutton("Save Journal",con=get(".AddNewJournalWidget2",env=.rqda),handler=function(h,...){
-            title <- ginput("Enter new file name. ",text=Sys.time(), icon="info")
+            ## title <- ginput("Enter new file name. ",text=Sys.time(), icon="info")
+            title <- as.character(Sys.time())
             if (!is.na(title)){
-            if (nrow(dbGetQuery(.rqda$qdacon,sprintf("select name from journal where name=='%s'",enc(title))))!=0) {
+            if (nrow(dbGetQuery(.rqda$qdacon,sprintf("select name from journal where name='%s'",enc(title))))!=0) {
                 title <- paste("New",title)
             }## Make sure it is unique
             content <- svalue(textW)
