@@ -14,7 +14,7 @@
   options(andMethod=c("overlap","exact","inclusion"))
   assign("optOld",optOld,env=.rqda)
   if (interactive()) {
-     message("\nUse 'RQDA()' to start the programe.\n")
+     packageStartupMessage("\nUse 'RQDA()' to start the programe.\n")
      RQDA()
    }
 }
@@ -23,3 +23,19 @@
   cat("Bye, RQDA is unloaded.\n")
   options(.rqda$optOld)
 }
+
+
+## use cam name conventions; duplicated the original functions for smooth transition.
+## must in ultis.R
+## crossCodes <- CrossCode
+crossTwoCodes <- CrossTwo
+exportCodings <- ExportCoding
+getCaseNames <- GetCaseName
+getCaseIds <- GetCaseId
+getCodingTable <- GetCodingTable
+queryFiles <- QueryFile
+getFileNames <- GetFileName
+getFileIds <- GetFileId
+getFileIdSets <- GetFileIdSets
+getAttr <- GetAttr
+showSubset <- ShowSubset
\ No newline at end of file
